#[non_exhaustive]pub enum Error {
Variant(Error),
InvalidBusName(String, String),
InvalidWellKnownName(String),
InvalidUniqueName(String),
InvalidInterfaceName(String),
InvalidMemberName(String),
InvalidPropertyName(String),
InvalidErrorName(String),
InvalidName(&'static str),
InvalidNameConversion {
from: &'static str,
to: &'static str,
},
}Expand description
The error type for zbus_names.
The various errors that can be reported by this crate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Variant(Error)
InvalidBusName(String, String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid bus name. The strings describe why the bus name is neither a valid unique nor well-known name, respectively.
InvalidWellKnownName(String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid well-known bus name.
InvalidUniqueName(String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid unique bus name.
InvalidInterfaceName(String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid interface name.
InvalidMemberName(String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid member (method or signal) name.
InvalidPropertyName(String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid property name.
InvalidErrorName(String)
This variant is no longer returned from any of our API.Use Error::InvalidName instead.
Invalid error name.
InvalidName(&'static str)
An invalid name.
InvalidNameConversion
Invalid conversion from name type from to name type to.